@@ -4,18 +4,15 @@
 
 using namespace seqan;
 
-int main(int argc, char ** argv)
+int main()
 {
-    if (argc != 2)
-    {
-        std::cerr << "USAGE: " << argv[0] << " SEQUENCE.fasta\n";
-        return 1;
-    }
+    CharString path = SEQAN_PATH_TO_ROOT();
+    append(path, "/core/demos/seq_io/example.fa");
     
     FaiIndex faiIndex;
 
     // Try to read the FAI index.
-    bool readSuccess = (read(faiIndex, argv[1]) == 0);
+    bool readSuccess = (read(faiIndex, toCString(path)) == 0);
     if (!readSuccess)
         std::cerr << "Could not read the FAI index.  Not fatal, we can just build it.\n";
 
@@ -23,7 +20,7 @@ int main(int argc, char ** argv)
     // building into memory succeeded, we try to write it out.
     if (!readSuccess)
     {
-        if (build(faiIndex, argv[1]) != 0)
+        if (build(faiIndex, toCString(path)) != 0)
         {
             std::cerr << "FATAL: Could not build FAI index.\n";
             return 1;
@@ -38,20 +35,20 @@ int main(int argc, char ** argv)
 
     // Now, read the first 1000 characters of chr1.
     unsigned idx = 0;
-    if (!getIdByName(faiIndex, "chr1", idx))
+    if (!getIdByName(faiIndex, "chr", idx))
     {
         std::cerr << "FATAL: chr1 not found in FAI index.\n";
         return 1;
     }
     CharString seq;
-    if (readRegion(seq, faiIndex, idx, 0, 1000) != 0)
+    if (readRegion(seq, faiIndex, idx, 0, 100) != 0)
     {
         std::cerr << "FATAL: Problem reading FASTA file through FAI index.\n";
         return 1;
     }
 
-    // Now print the first 1000 characters we just read.
-    std::cerr << "chr1:1-1000 = " << seq << "\n";
+    // Now print the first 100 characters we just read.
+    std::cout << "chr:1-100 = " << seq << "\n";
     
     return 0;
 }
