@@ -49,6 +49,9 @@ namespace seqan {
 // Forwards
 // ==========================================================================
 
+// Required for _checkStringRestrictions().
+inline std::string getFileExtension(ArgParseArgument const & me, unsigned pos);
+
 // ==========================================================================
 // Tags, Classes, Enums
 // ==========================================================================
@@ -148,12 +151,14 @@ public:
     enum ArgumentType
     {
         // argument is
-        STRING,     // .. a string
-        INTEGER,    // .. an integer
-        INT64,      // .. a 64 bit integer
-        DOUBLE,     // .. a float
-        INPUTFILE,  // .. an inputfile (implicitly also a string)
-        OUTPUTFILE  // .. an outputfile (implicitly also a string)
+        STRING,      // .. a string
+        INTEGER,     // .. an integer
+        INT64,       // .. a 64 bit integer
+        DOUBLE,      // .. a float
+        INPUTFILE,   // .. an inputfile (implicitly also a string)
+        OUTPUTFILE,  // .. an outputfile (implicitly also a string)
+        INPUTPREFIX, // .. an inputprefix (implicitly also a string)
+        OUTPUTPREFIX // .. an outoutprefix (implicitly also a string)
     };
 
 
@@ -170,6 +175,8 @@ public:
     // ----------------------------------------------------------------------------
     std::vector<std::string>  defaultValue;
     std::vector<std::string>  value;
+    // Override for the file extension;  only used for input/output file arguments.
+    std::vector<std::string> _fileExtensions;
 
     // ----------------------------------------------------------------------------
     // Members for restrictions
@@ -178,6 +185,14 @@ public:
     std::string           maxValue;
     std::vector<std::string> validValues;
 
+    // ----------------------------------------------------------------------------
+    // Tags
+    // ----------------------------------------------------------------------------
+    // Tags can be used to attach hints to the arguments (and options).  Currently,
+    // this is used for tagging the "-file-ext" arguments as "file-ext-override"
+    // and "gkn-ignore" for ignoring in GKN.
+    std::vector<std::string> tags;
+
     // ----------------------------------------------------------------------------
     // Members to help text
     // ----------------------------------------------------------------------------
@@ -199,40 +214,6 @@ public:
         maxValue(""),
         _helpText("")
     {}
-
-    ArgParseArgument(ArgParseArgument const & other) :
-        _argumentType(other._argumentType),
-        _numberOfValues(other._numberOfValues),
-        _argumentLabel(other._argumentLabel),
-        _isListArgument(other._isListArgument),
-        defaultValue(other.defaultValue),
-        value(other.value),
-        minValue(other.minValue),
-        maxValue(other.maxValue),
-        validValues(other.validValues),
-        _helpText(other._helpText)
-    {}
-
-    // TODO(holtgrew): This is superflous, generated by the compiler.
-    ArgParseArgument & operator=(ArgParseArgument const & other)
-    {
-        if (this != &other)
-        {
-            _argumentType = other._argumentType;
-            _numberOfValues = other._numberOfValues;
-            _argumentLabel = other._argumentLabel;
-            _isListArgument = other._isListArgument;
-            defaultValue = other.defaultValue;
-            value = other.value;
-            minValue = other.minValue;
-            maxValue = other.maxValue;
-            validValues = other.validValues;
-            _helpText = other._helpText;
-        }
-
-        return *this;
-    }
-
 };
 
 // ==========================================================================
@@ -277,6 +258,14 @@ inline std::string _typeToString(ArgParseArgument const & me)
         typeName = "outputfile";
         break;
 
+    case ArgParseArgument::INPUTPREFIX:
+        typeName = "inputprefix";
+        break;
+
+    case ArgParseArgument::OUTPUTPREFIX:
+        typeName = "outputprefix";
+        break;
+
     default:
         typeName = "unknown";
         break;
@@ -354,7 +343,9 @@ inline bool isStringArgument(ArgParseArgument const & me)
 {
     return (me._argumentType == ArgParseArgument::STRING) ||
            (me._argumentType == ArgParseArgument::INPUTFILE) ||
-           (me._argumentType == ArgParseArgument::OUTPUTFILE);
+           (me._argumentType == ArgParseArgument::OUTPUTFILE) ||
+           (me._argumentType == ArgParseArgument::INPUTPREFIX) ||
+           (me._argumentType == ArgParseArgument::OUTPUTPREFIX) ;
 }
 
 // ----------------------------------------------------------------------------
@@ -446,7 +437,7 @@ inline bool isInt64Argument(ArgParseArgument const & me)
 ..class:Class.ArgParseArgument
 ..summary:Returns whether the argument is a double.
 ..cat:Miscellaneous
-..signature:isListArgument(argument)
+..signature:isDoubleArgument(argument)
 ..param.argument:The @Class.ArgParseArgument@ object.
 ...type:Class.ArgParseArgument
 ..returns:$true$ if the argument argument is a double argument.
@@ -466,7 +457,7 @@ inline bool isDoubleArgument(ArgParseArgument const & me)
 /*!
  * @fn ArgParseArgument#isInputFileArgument
  * @headerfile <seqan/arg_parse.h>
- * @brief Returns whether the argument is a input file integer.
+ * @brief Returns whether the argument is a input file.
  *
  * @signature bool isInputFileArgument(arg);
  *
@@ -480,7 +471,7 @@ inline bool isDoubleArgument(ArgParseArgument const & me)
 ..class:Class.ArgParseArgument
 ..summary:Returns whether the argument is an input file.
 ..cat:Miscellaneous
-..signature:isListArgument(argument)
+..signature:isOutputFileArgument(argument)
 ..param.argument:The @Class.ArgParseArgument@ object.
 ...type:Class.ArgParseArgument
 ..returns:$true$ if the argument argument is an input file argument.
@@ -500,7 +491,7 @@ inline bool isInputFileArgument(ArgParseArgument const & me)
 /*!
  * @fn ArgParseArgument#isOutputFileArgument
  * @headerfile <seqan/arg_parse.h>
- * @brief Returns whether the argument is a output file integer.
+ * @brief Returns whether the argument is a output file.
  *
  * @signature bool isOutputFileArgument(arg);
  *
@@ -514,7 +505,7 @@ inline bool isInputFileArgument(ArgParseArgument const & me)
 ..class:Class.ArgParseArgument
 ..summary:Returns whether the argument is an output file.
 ..cat:Miscellaneous
-..signature:isListArgument(argument)
+..signature:isOutputFileArgument(argument)
 ..param.argument:The @Class.ArgParseArgument@ object.
 ...type:Class.ArgParseArgument
 ...type:Class.ArgParseOption
@@ -528,6 +519,76 @@ inline bool isOutputFileArgument(ArgParseArgument const & me)
     return me._argumentType == ArgParseArgument::OUTPUTFILE;
 }
 
+// ----------------------------------------------------------------------------
+// Function isOutputPrefixArgument()
+// ----------------------------------------------------------------------------
+
+/*!
+ * @fn ArgParseArgument#isOutputPrefixArgument
+ * @headerfile <seqan/arg_parse.h>
+ * @brief Returns whether the argument is an output prefix.
+ *
+ * @signature bool isOutputPrefixArgument(arg);
+ *
+ * @param arg The ArgParseArgument to query.
+ *
+ * @return bool <tt>true</tt> if it is an output prefix argument, <tt>false</tt> otherwise.
+ */
+
+/**
+ .Function.isOutputPrefixArgument
+ ..class:Class.ArgParseArgument
+ ..summary:Returns whether the argument is an output file.
+ ..cat:Miscellaneous
+ ..signature:isOutputPrefixArgument(argument)
+ ..param.argument:The @Class.ArgParseArgument@ object.
+ ...type:Class.ArgParseArgument
+ ...type:Class.ArgParseOption
+ ..returns:$true$ if the argument argument is an output file argument.
+ ..see:Memfunc.ArgParseArgument#ArgParseArgument.param.argumentType
+ ..include:seqan/arg_parse.h
+ */
+
+inline bool isOutputPrefixArgument(ArgParseArgument const & me)
+{
+    return me._argumentType == ArgParseArgument::OUTPUTPREFIX;
+}
+
+// ----------------------------------------------------------------------------
+// Function isOutputFileArgument()
+// ----------------------------------------------------------------------------
+
+/*!
+ * @fn ArgParseArgument#isInputPrefixArgument
+ * @headerfile <seqan/arg_parse.h>
+ * @brief Returns whether the argument is an input prefix argument.
+ *
+ * @signature bool isInputPrefixArgument(arg);
+ *
+ * @param arg The ArgParseArgument to query.
+ *
+ * @return bool <tt>true</tt> if it is an input prefix argument, <tt>false</tt> otherwise.
+ */
+
+/**
+ .Function.isInputPrefixArgument
+ ..class:Class.ArgParseArgument
+ ..summary:Returns whether the argument is an output file.
+ ..cat:Miscellaneous
+ ..signature:isInputPrefixArgument(argument)
+ ..param.argument:The @Class.ArgParseArgument@ object.
+ ...type:Class.ArgParseArgument
+ ...type:Class.ArgParseOption
+ ..returns:$true$ if the argument argument is an input prefix argument.
+ ..see:Memfunc.ArgParseArgument#ArgParseArgument.param.argumentType
+ ..include:seqan/arg_parse.h
+ */
+
+inline bool isInputPrefixArgument(ArgParseArgument const & me)
+{
+    return me._argumentType == ArgParseArgument::INPUTPREFIX;
+}
+    
 // ----------------------------------------------------------------------------
 // Function getArgumentLabel()
 // ----------------------------------------------------------------------------
@@ -569,6 +630,8 @@ inline std::string const getArgumentLabel(ArgParseArgument const & me)
         std::string baseLabel = "";
         if (isInputFileArgument(me) || isOutputFileArgument(me))
             baseLabel = "FILE";
+        else if (isInputPrefixArgument(me) || isOutputPrefixArgument(me))
+            baseLabel = "PREFIX";
         else if (isStringArgument(me))
             baseLabel = "STR";
         else if (isIntegerArgument(me) || isDoubleArgument(me))
@@ -874,7 +937,7 @@ inline void _checkNumericArgument(ArgParseArgument const & me, std::string const
     {
         std::stringstream what;
         what << "the given value '" << value << "' cannot be casted to " << _typeToString(me);
-        throw ParseException(what.str());
+        SEQAN_THROW(ParseError(what.str()));
     }
 
     if (!_isInInterval<TNumerical>(value, me.minValue, me.maxValue))
@@ -884,7 +947,7 @@ inline void _checkNumericArgument(ArgParseArgument const & me, std::string const
              << (me.minValue != "" ? me.minValue : "-inf") << ":"
              << (me.maxValue != "" ? me.maxValue : "+inf") << "]";
 
-        throw ParseException(what.str());
+        SEQAN_THROW(ParseError(what.str()));
     }
 }
 
@@ -907,11 +970,15 @@ inline bool _compareExtension(std::string const & str, std::string const & ext)
 // Helper Function _checkStringRestrictions()
 // ----------------------------------------------------------------------------
 
-inline void _checkStringRestrictions(ArgParseArgument const & me, std::string const & value)
+// The parameter i gives the index of the value in the argument.
+
+inline void _checkStringRestrictions(ArgParseArgument const & me, std::string value,
+                                     unsigned i)
 {
     typedef std::vector<std::string>::const_iterator TVectorIterator;
 
-    if (!empty(me.validValues))
+    // we only check valid values for files and string arguments, but not for prefix arguments
+    if (!empty(me.validValues) && !(isInputPrefixArgument(me) || isOutputPrefixArgument(me)))
     {
         bool isContained = false;
         for (TVectorIterator validValue = me.validValues.begin();
@@ -921,10 +988,10 @@ inline void _checkStringRestrictions(ArgParseArgument const & me, std::string co
             // if it is an input or output file, we only check the file endings
             if (isInputFileArgument(me) || isOutputFileArgument(me))
             {
-                if (length(*validValue) > length(value))
+                if (length(*validValue) > length(getFileExtension(me, i)))
                     continue;
                 else
-                    isContained |= _compareExtension(value, *validValue);
+                    isContained |= _compareExtension(getFileExtension(me, i), *validValue);
             }
             else
             {
@@ -936,10 +1003,10 @@ inline void _checkStringRestrictions(ArgParseArgument const & me, std::string co
         if (!isContained)
         {
             std::stringstream what;
-            what << "the given value '" << value <<
-            "' is not in the list of allowed" <<
-            ((isInputFileArgument(me) || isOutputFileArgument(me)) ? " file extensions " : " values ") <<
-            "[";
+            if (isInputFileArgument(me) || isOutputFileArgument(me))
+                what << "the given path '" << value << "' does not have one of the valid file extensions [";
+            else
+                what << "the given value '" << value << "' is not in the list of allowed values [";
             for (TVectorIterator validValue = me.validValues.begin();
                  validValue != me.validValues.end();
                  ++validValue)
@@ -949,7 +1016,9 @@ inline void _checkStringRestrictions(ArgParseArgument const & me, std::string co
                 what << ((isInputFileArgument(me) || isOutputFileArgument(me)) ? "*" : "") << *validValue;
             }
             what << "]";
-            throw ParseException(what.str());
+            if (i < me._fileExtensions.size())
+                what << "; the file extension was overridden to be '" << getFileExtension(me, i) << "'";
+            SEQAN_THROW(ParseError(what.str()));
         }
     }
 }
@@ -958,21 +1027,32 @@ inline void _checkStringRestrictions(ArgParseArgument const & me, std::string co
 // Function _checkValue()
 // ----------------------------------------------------------------------------
 
-inline void _checkValue(ArgParseArgument const & me, std::string const & value)
+// Check value before or after assignment.
+//
+// The parameter i gives the index of the value to check for overriding the extension in case of file arguments.
+
+inline void _checkValue(ArgParseArgument const & me, std::string val, unsigned i = 0)
 {
     // type checks
     if (isIntegerArgument(me))
-        _checkNumericArgument<int>(me, value);
+        _checkNumericArgument<int>(me, val);
 
     if (isInt64Argument(me))
-        _checkNumericArgument<__int64>(me, value);
+        _checkNumericArgument<__int64>(me, val);
 
     if (isDoubleArgument(me))
-        _checkNumericArgument<double>(me, value);
+        _checkNumericArgument<double>(me, val);
 
     // check valid values
     if (isStringArgument(me))
-        _checkStringRestrictions(me, value);
+        _checkStringRestrictions(me, val, i);
+}
+
+inline void _checkValue(ArgParseArgument const & me)
+{
+    unsigned i = 0;
+    for (std::vector<std::string>::const_iterator it = me.value.begin(); it != me.value.end(); ++it, ++i)
+        _checkValue(me, *it, i);
 }
 
 // ----------------------------------------------------------------------------
@@ -994,14 +1074,13 @@ Otherwise the value will be overwritten.
 ..include:seqan/arg_parse.h
 */
 
-inline void _assignArgumentValue(ArgParseArgument & me, std::string const & value) throw (ParseException)
+inline void _assignArgumentValue(ArgParseArgument & me, std::string const & value)
 {
-    // check values
-    _checkValue(me, value);
-
     // assignment
     if (isListArgument(me)) // just append
+    {
         appendValue(me.value, value, Exact());
+    }
     else
     {
         // check if we already set all expected arguments
@@ -1235,6 +1314,89 @@ inline unsigned numberOfAllowedValues(ArgParseArgument const & me)
     return me._numberOfValues;
 }
 
+// ----------------------------------------------------------------------------
+// Function getFileExtension()
+// ----------------------------------------------------------------------------
+
+/*!
+ * @fn ArgParseArgument#getFileExtension
+ * @headerfile <seqan/arg_parse.h>
+ * @brief Returns the file extension for the given file argument.
+ *
+ * Only valid when argument is an INPUTFILE or OUTPUTFILE.
+ *
+ * Halts the program if not an input or output file argument.
+ *
+ * Can be overridden with special hidden options.
+ * For arguments, you can pass <tt>--arg-&lt;num&gt;-file-ext</tt> for argument <tt>num</tt>.
+ * For parameters, you can pass <tt>--&lt;param-name&gt;-file-ext</tt> for the option named <tt>param-name</tt>.
+ *
+ * @signature std::string getFileExtension(arg[, pos]);
+ *
+ * @param arg The ArgParseArgument to query.
+ * @param pos The position of the value to retrieve if multiple values (<tt>unsigned</tt>).
+ *
+ * @return std::string The file extension, empty if no extension or not set.
+ */
+
+/**
+.Function.ArgParseArgument#getFileExtension
+..class:Class.ArgParseArgument
+..summary:Returns the file extension for the given file argument.
+..description:Only valid when argument is an INPUTFILE or OUTPUTFILE.
+..cat:Miscellaenous
+..signature:std::string getFileExtension(argument[, pos]);
+..param.argument:The @Class.ArgParseArgument@ object.
+...type:Class.ArgParseArgument
+..param.pos:The position of the value if multiple values are allowed.
+...type:nolink:$unsigned$
+..returns:A $std::string$ with the extension of the file, if any.  Empty if no extension.
+..remarks:Halts the program if the argument is not an input or output file argument.
+..remarks:Note that you can
+..include:seqan/arg_parse.h
+*/
+
+inline std::string getFileExtension(ArgParseArgument const & me, unsigned pos = 0)
+{
+    if (me._argumentType != ArgParseArgument::INPUTFILE &&
+        me._argumentType != ArgParseArgument::OUTPUTFILE)
+        SEQAN_FAIL("Cannot get file extension from non-file argument/option.");
+
+    // Short-circuit to override file extension if set.
+    if (pos < me._fileExtensions.size())
+    {
+        std::string result = me._fileExtensions[pos];
+        if (!result.empty() && result[0] != '.')
+            result.insert(0, ".");
+        return result;
+    }
+
+    // Get argument value and break if empty.
+    std::string value = getArgumentValue(me, pos);
+    if (value.empty())
+        return "";
+
+    // If there is a list of valid values then we look for each of these in the path.
+    if (!me.validValues.empty())
+    {
+        for (unsigned i = 0; i < length(me.validValues); ++i)
+        {
+            unsigned len = std::min(me.validValues[i].size(), value.size());
+            std::string tmp = value.substr(value.size() - len);
+            std::transform(tmp.begin(), tmp.end(), tmp.begin(), ::tolower);
+            if (tmp == me.validValues[i])
+                return me.validValues[i];
+        }
+        return "";
+    }
+
+    // Fall back to finding position of last dot.  Return suffix if found and empty string if not.
+    size_t dotPos = value.find_last_of('.');
+    if (dotPos == std::string::npos)
+        return "";
+    return value.substr(dotPos + 1);
+}
+
 } // namespace seqan
 
 #endif // SEQAN_CORE_INCLUDE_SEQAN_ARG_PARSE_ARG_PARSE_ARGUMENT_H_
