@@ -54,7 +54,11 @@ namespace SEQAN_NAMESPACE_MAIN
  * @signature template <typename THost>
  *            class Segment<THost, SuffixSegment>;
  *
- * @tparam THost The underlying @link SequenceConcept sequence@ type.
+ * @tparam THost The underlying @link SequenceConcept sequence @endlink type.
+ *
+ * @see InfixSegment
+ * @see PrefixSegment
+ * @aka substring
  */
 
 /**
@@ -119,6 +123,7 @@ If $begin$ is omitted, the suffix segment corresponding to
 the whole sequence $host$ is constructed.
 This is the same segment that is returned by @Function.goBegin@.
 */
+    SEQAN_HOST_DEVICE
     Segment():
         data_host(),
         data_begin_position(0)
@@ -169,6 +174,7 @@ SEQAN_CHECKPOINT
 SEQAN_CHECKPOINT
     }
 
+    SEQAN_HOST_DEVICE
     ~ Segment()
     {
 SEQAN_CHECKPOINT
@@ -216,7 +222,7 @@ SEQAN_CHECKPOINT
 //////////////////////////////////////////////////////////////////////////////
 
 template <typename THost_>
-inline typename Parameter_<THost_>::Type
+SEQAN_HOST_DEVICE inline typename Parameter_<THost_>::Type
 host(Segment<THost_, SuffixSegment> & me)
 {
 SEQAN_CHECKPOINT
@@ -224,7 +230,7 @@ SEQAN_CHECKPOINT
 }
 
 template <typename THost_>
-inline typename Parameter_<THost_>::Type
+SEQAN_HOST_DEVICE inline typename Parameter_<THost_>::Type
 host(Segment<THost_, SuffixSegment> const & me)
 {
 SEQAN_CHECKPOINT
@@ -252,7 +258,7 @@ SEQAN_CHECKPOINT
 //____________________________________________________________________________
 
 template <typename THost_>
-inline typename Iterator<Segment<THost_, SuffixSegment>, Standard>::Type
+SEQAN_HOST_DEVICE inline typename Iterator<Segment<THost_, SuffixSegment>, Standard>::Type
 begin(Segment<THost_, SuffixSegment> & me,
     Standard)
 {
@@ -260,7 +266,7 @@ SEQAN_CHECKPOINT
     return begin(host(me), Standard()) + me.data_begin_position;
 }
 template <typename THost_>
-inline typename Iterator<Segment<THost_, SuffixSegment> const, Standard>::Type
+SEQAN_HOST_DEVICE inline typename Iterator<Segment<THost_, SuffixSegment> const, Standard>::Type
 begin(Segment<THost_, SuffixSegment> const & me,
     Standard)
 {
