@@ -53,6 +53,20 @@ namespace seqan {
 // Specialization Journaled String
 // ----------------------------------------------------------------------------
 
+/*!
+ * @class JournaledString
+ * @extends String
+ * @headerfile <seqan/sequence_journaled.h>
+ * @brief Journaled versions of arbitrary underlying strings.
+ *
+ * @signature <typename THostSpec[, typename TJournalSpec[, typename TBufferSpec]]>
+ *            class String<Journaled<THostSpec, TJournalSpec, TBufferSpec> >;
+ *
+ * @tparam THostSpec    Specialization type for the host string.
+ * @tparam TJournalSpec Specialization type for the journal.  Default: <tt>SortedArray</tt>.
+ * @tparam TBufferSpec  Specialization type for the buffer string.  Default: <tt>Alloc&lt;&gt;</tt>.
+ */
+
 /**
 .Spec.Journaled String
 ..cat:Sequences
@@ -109,7 +123,6 @@ public:
     String(String const & other)
     {
         SEQAN_CHECKPOINT;
-        assign(_holder, other._holder);
         set(*this, other);
     }
 
@@ -124,11 +137,8 @@ public:
     String &
     operator=(String const & other)
     {
-        SEQAN_CHECKPOINT;
-        //TODO (rmaerker): should copy the holder, too. What is intended with the assignment - copy or set?
-        //TODO (rmaerker): missing self-assignment test. What happens with ptr of Holder in self-assignment
-        // assign(_holder, other._holder);
-        assign(*this, other);
+        if (this != &other)
+            set(*this, other);
         return *this;
     }
 
@@ -167,6 +177,17 @@ public:
 // Metafunction Host
 // ----------------------------------------------------------------------------
 
+/*!
+ * @mfn JournaledString#Host
+ * @brief The host type.
+ *
+ * @signature Host<TJournaledString>::Type;
+ *
+ * @tparam TJournaledString The JournaldString to get the host type for.
+ *
+ * @return Type The host type.
+ */
+
 /**
 .Metafunction.Host
 ..param.T.type:Spec.Journaled String
@@ -189,6 +210,17 @@ struct Host<String<TValue, Journaled<THostSpec, TJournalSpec, TBufferSpec> > con
 // Metafunction InsertionBuffer
 // ----------------------------------------------------------------------------
 
+/*!
+ * @mfn JournaledString#InsertionBuffer
+ * @brief Return type of insertion buffer string for a journaled string.
+ *
+ * @signature InsertionBuffer<TJournaledString>::Type;
+ *
+ * @tparam TJournaledString The journaled string to get the insertion buffer type for.
+ *
+ * @return Type The insertion buffer type.
+ */
+
 /**
 .Metafunction.InsertionBuffer
 ..cat:Sequences
@@ -311,6 +343,17 @@ struct Value<String<TValue, Journaled<THostSpec, TJournalSpec, TBufferSpec> > co
 // Metafunction JournalType
 // ----------------------------------------------------------------------------
 
+/*!
+ * @mfn JournaledString#JournalType
+ * @brief Query a JournaledString for its journal type.
+ *
+ * @signature JournalType<TJournaledString>::Type;
+ *
+ * @tparam TJournaledString The JournaledString to query.
+ *
+ * @return Type the journal type.
+ */
+
 /**
 .Metafunction.JournalType
 ..cat:Sequences
@@ -373,12 +416,51 @@ operator<<(TStream & stream, String<TValue, Journaled<THostSpec, TJournalSpec, T
 // Function assign
 // ----------------------------------------------------------------------------
 
-// Assignment always resizes the insertion buffer and copies the contents of
-// source into the insertion buffer.  Even when assigning a journaled string
-// to a journaled string!
+// Assignment of two identical journaled strings.
+template <typename TValue, typename THostSpec, typename TJournalSpec, typename TBufferSpec,
+          typename TExpand>
+inline void
+assign(String<TValue, Journaled<THostSpec, TJournalSpec, TBufferSpec> > & target,
+       String<TValue, Journaled<THostSpec, TJournalSpec, TBufferSpec> > const & source,
+       Tag<TExpand> /*tag*/)
+{
+    set(target, source);
+}
+
+
+template <typename TValue, typename THostSpec, typename TJournalSpec, typename TBufferSpec>
+inline void
+assign(String<TValue, Journaled<THostSpec, TJournalSpec, TBufferSpec> > & target,
+       String<TValue, Journaled<THostSpec, TJournalSpec, TBufferSpec> > const & source)
+{
+    typedef String<TValue, Journaled<THostSpec, TJournalSpec, TBufferSpec> > TTarget;
+    assign(target, source, DefaultOverflowImplicit<TTarget>::Type());
+}
+
+template <typename TValue, typename THostSpec, typename TJournalSpec, typename TBufferSpec,
+          typename TExpand>
+inline void
+assign(String<TValue, Journaled<THostSpec, TJournalSpec, TBufferSpec> > & target,
+       String<TValue, Journaled<THostSpec, TJournalSpec, TBufferSpec> > & source,
+       Tag<TExpand>)
+{
+    typedef String<TValue, Journaled<THostSpec, TJournalSpec, TBufferSpec> > TSource;
+    assign(target, static_cast<TSource const &>(source), Tag<TExpand>());
+}
+
+template <typename TValue, typename THostSpec, typename TJournalSpec, typename TBufferSpec>
+inline void
+assign(String<TValue, Journaled<THostSpec, TJournalSpec, TBufferSpec> > & target,
+       String<TValue, Journaled<THostSpec, TJournalSpec, TBufferSpec> > & source)
+{
+    typedef String<TValue, Journaled<THostSpec, TJournalSpec, TBufferSpec> > TTarget;
+    assign(target, source, typename DefaultOverflowImplicit<TTarget>::Type());
+}
+
+// Assignment of a journaled string with another string type always resizes the
+// insertion buffer and copies the contents of source into the insertion buffer.
 template <typename TValue, typename THostSpec, typename TJournalSpec, typename TBufferSpec, typename TSource>
-inline
-void
+inline void
 assign(String<TValue, Journaled<THostSpec, TJournalSpec, TBufferSpec> > & target,
        TSource const & source)
 {
@@ -388,8 +470,7 @@ assign(String<TValue, Journaled<THostSpec, TJournalSpec, TBufferSpec> > & target
 }
 
 template <typename TValue, typename THostSpec, typename TJournalSpec, typename TBufferSpec, typename TSource>
-inline
-void
+inline void
 assign(String<TValue, Journaled<THostSpec, TJournalSpec, TBufferSpec> > & target,
        TSource & source)
 {
@@ -410,10 +491,10 @@ set(String<TValue, Journaled<THostSpec, TJournalSpec, TBufferSpec> > & target,
     String<TValue, Journaled<THostSpec, TJournalSpec, TBufferSpec> > const & source)
 {
     SEQAN_CHECKPOINT;
-    target._holder = source._holder;
-    target._insertionBuffer = source._insertionBuffer;
-    target._journalEntries = source._journalEntries;
-    target._length = source._length;
+    assign(target._holder, source._holder);
+    assign(target._insertionBuffer, source._insertionBuffer);
+    assign(target._journalEntries, source._journalEntries);
+    assign(target._length, source._length);
 }
 
 template <typename TValue, typename THostSpec, typename TJournalSpec, typename TBufferSpec>
@@ -441,6 +522,16 @@ set(String<TValue, Journaled<THostSpec, TJournalSpec, TBufferSpec> > & target,
 // Function setHost
 // ----------------------------------------------------------------------------
 
+/*!
+ * @fn JournaledString#setHost
+ * @brief Set the host of a JournaledString.
+ *
+ * @signature void setHost(js, str);
+ *
+ * @param js  The JournaledString to set the host for.
+ * @param str The string to set as the host.
+ */
+
 /**
 .Function.setHost:
 ..class:Spec.Journaled String
@@ -463,6 +554,17 @@ setHost(String<TValue, Journaled<THostSpec, TJournalSpec, TBufferSpec> > & journ
 // Function host
 // ----------------------------------------------------------------------------
 
+/*!
+ * @fn JournaledString#host
+ * @brief Return the host of a JournaledString.
+ *
+ * @signature THost host(js);
+ *
+ * @param[in] js The JournaledString to query.
+ *
+ * @return THost Reference to the host of <tt>js</tt>.
+ */
+
 /**
 .Function.host:
 ..class:Spec.Journaled String
@@ -491,6 +593,15 @@ host(String<TValue, Journaled<THostSpec, TJournalSpec, TBufferSpec> > const & jo
 // Function clear
 // ----------------------------------------------------------------------------
 
+/*!
+ * @fn JournaledString#clear
+ * @brief Remove all changes from the journal, resetting the JournaledString to its state after construction.
+ *
+ * @signature void clear(js);
+ *
+ * @param[in,out] js The JournaledString to clear.
+ */
+
 /**
 .Function.clear:
 ..class:Spec.Journaled String
@@ -508,10 +619,33 @@ clear(String<TValue, Journaled<THostSpec, TJournalSpec, TBufferSpec> > & journal
     _setLength(journaledString, length(host(journaledString)));
 }
 
+// ----------------------------------------------------------------------------
+// Function reset
+// ----------------------------------------------------------------------------
+
+template <typename TValue, typename THostSpec, typename TJournalSpec, typename TBufferSpec>
+inline void
+reset(String<TValue, Journaled<THostSpec, TJournalSpec, TBufferSpec> > & journaledString)
+{
+    clear(journaledString._holder);
+    clear(journaledString._insertionBuffer);
+    clear(journaledString._journalEntries);
+    _setLength(journaledString, 0u);
+}
+
 // ----------------------------------------------------------------------------
 // Function flatten
 // ----------------------------------------------------------------------------
 
+/*!
+ * @fn JournaledString#flatten
+ * @brief Apply the journal to the underlying string, modifying the underlying string.
+ *
+ * @signature void flatten(js);
+ *
+ * @param[in,out] js The JournaledString to flatten.
+ */ 
+
 /**
 .Function.flatten:
 ..class:Spec.Journaled String  
@@ -794,6 +928,18 @@ getValue(String<TValue, Journaled<THostSpec, TJournalSpec, TBufferSpec> > const
 // Function virtualToHostPosition()
 // --------------------------------------------------------------------------
 
+/*!
+ * @fn JournaledString#virtualToHostPosition
+ * @brief Translates virtual (view) position to position in host.
+ *
+ * @signature TPos virtualToHostPosition(js, pos);
+ *
+ * @param js  The JournaledString to translate the position for.
+ * @param pos The virtual position to translate.
+ *
+ * @return TPos Position in the host.
+ */
+
 /**
 .Function.Journaled String#virtualToHostPosition
 ..class:Spec.Journaled String
@@ -823,6 +969,18 @@ virtualToHostPosition(String<TValue, Journaled<THostSpec, TJournalSpec, TBufferS
 // function hostToVirtualPosition()
 //---------------------------------------------------
 
+/*!
+ * @fn JournaledString#hostToVirtualPosition
+ * @brief Translates host position to virtual position.
+ *
+ * @signature TPos virtualToHostPosition(js, pos);
+ *
+ * @param js  The JournaledString to translate the position for.
+ * @param pos The host position to translate.
+ *
+ * @return TPos The virtual view position.
+ */
+
 /**
 .Function.Journaled String#hostToVirtualPosition
 ..class:Spec.Journaled String
@@ -874,6 +1032,24 @@ _setLength(String<TValue, Journaled<THostSpec, TJournalSpec, TBufferSpec> > & jo
     journaledString._length = newLength;
 }
 
+// ----------------------------------------------------------------------------
+// Function _journalEntries
+// ----------------------------------------------------------------------------
+
+template <typename TValue, typename THostSpec, typename TJournalSpec, typename TBufferSpec>
+inline typename JournalType<String<TValue, Journaled<THostSpec, TJournalSpec, TBufferSpec> > >::Type &
+_journalEntries(String<TValue, Journaled<THostSpec, TJournalSpec, TBufferSpec> > & journaledString)
+{
+    return journaledString._journalEntries;
+}
+
+template <typename TValue, typename THostSpec, typename TJournalSpec, typename TBufferSpec>
+inline typename JournalType<String<TValue, Journaled<THostSpec, TJournalSpec, TBufferSpec> > const>::Type &
+_journalEntries(String<TValue, Journaled<THostSpec, TJournalSpec, TBufferSpec> > const & journaledString)
+{
+    return journaledString._journalEntries;
+}
+
 // --------------------------------------------------------------------------
 // Function replace()
 // --------------------------------------------------------------------------
