@@ -59,7 +59,7 @@
 #include "test_align_global_alignment_specialized.h"
 
 #include "test_align_alignment_operations.h"
-
+#include "test_evaluate_alignment.h"
 
 SEQAN_DEFINE_TEST(test)
 {
@@ -106,6 +106,9 @@ SEQAN_BEGIN_TESTSUITE(test_align)
     SEQAN_CALL_TEST(test_align_gaps_array_gaps_clipping_gaps_leading);
     SEQAN_CALL_TEST(test_align_gaps_array_gaps_clipping_gaps_trailing);
     SEQAN_CALL_TEST(test_align_gaps_array_gaps_clear_clipping);
+    SEQAN_CALL_TEST(test_align_gaps_array_gaps_copy_gaps);
+    SEQAN_CALL_TEST(test_align_gaps_array_gaps_copy_clipping);
+    SEQAN_CALL_TEST(test_align_gaps_array_gaps_source_is_nothing);
 
     SEQAN_CALL_TEST(test_align_gaps_anchor_gaps_metafunctions);
     SEQAN_CALL_TEST(test_align_gaps_anchor_constructor_and_source);
@@ -130,6 +133,10 @@ SEQAN_BEGIN_TESTSUITE(test_align)
     SEQAN_CALL_TEST(test_align_gaps_anchor_gaps_clipping_gaps_leading);
     SEQAN_CALL_TEST(test_align_gaps_anchor_gaps_clipping_gaps_trailing);
     SEQAN_CALL_TEST(test_align_gaps_anchor_gaps_clear_clipping);
+    SEQAN_CALL_TEST(test_align_gaps_anchor_gaps_copy_gaps);
+    SEQAN_CALL_TEST(test_align_gaps_anchor_gaps_copy_clipping);
+    // TODO(holtgrew): Extend anchor gaps such that this works.
+    // SEQAN_CALL_TEST(test_align_gaps_anchor_gaps_source_is_nothing);
 
     // -----------------------------------------------------------------------
     // Test Gaps Iterators.
@@ -469,6 +476,9 @@ SEQAN_BEGIN_TESTSUITE(test_align)
     SEQAN_CALL_TEST(test_alignment_algorithms_fragments_gaps_semi_global_affine);
     SEQAN_CALL_TEST(test_alignment_algorithms_score_semi_global_affine);
 
+    // Global Alignment with Differnt Container Types
+    SEQAN_CALL_TEST(test_alignment_algorithms_global_different_container);
+
     // Local Alignment.
     SEQAN_CALL_TEST(test_alignment_algorithms_align_local_linear);
     SEQAN_CALL_TEST(test_alignment_algorithms_gaps_local_linear);
@@ -538,6 +548,9 @@ SEQAN_BEGIN_TESTSUITE(test_align)
     SEQAN_CALL_TEST(test_align_global_alignment_banded_shorter_interfaces_linear);
     SEQAN_CALL_TEST(test_align_global_alignment_banded_shorter_interfaces_affine);
 
+    // Global Alignment with Differnt Container Types
+    SEQAN_CALL_TEST(test_alignment_algorithms_global_banded_different_container);
+
     // Local Alignment.
     SEQAN_CALL_TEST(test_alignment_algorithms_align_local_linear_banded);
     SEQAN_CALL_TEST(test_alignment_algorithms_gaps_local_linear_banded);
@@ -590,6 +603,7 @@ SEQAN_BEGIN_TESTSUITE(test_align)
     // -----------------------------------------------------------------------
 
     SEQAN_CALL_TEST(test_align_integrate_align);
+    SEQAN_CALL_TEST(test_align_integrate_align_infix_of_infix);
 
     // -----------------------------------------------------------------------
     // Test Printing.
@@ -599,5 +613,11 @@ SEQAN_BEGIN_TESTSUITE(test_align)
     SEQAN_CALL_TEST(test_align_stream_gaps_stream);
     SEQAN_CALL_TEST(test_align_stream_align_write);
     SEQAN_CALL_TEST(test_align_stream_align_stream);
+
+    // -----------------------------------------------------------------------
+    // Test Alignment Evaluation
+    // -----------------------------------------------------------------------
+
+    SEQAN_CALL_TEST(test_align_compute_alignment_stats);
 }
 SEQAN_END_TESTSUITE
