@@ -1091,6 +1091,136 @@ void testAlignGapsClearClipping(TGapsSpec const & /*spec*/)
     }
 }
 
+// Test copying of gaps.
+
+template <typename TGapsSpec>
+void testAlignGapsCopyGaps(TGapsSpec const & /*spec*/)
+{
+    using namespace seqan;
+
+    typedef Dna5String                               TString;
+    typedef Gaps<TString, TGapsSpec>                 TGaps;
+
+    {
+        TString seq = "CGAT";
+        TGaps gaps(seq);
+        insertGaps(gaps, 4, 2);
+        insertGaps(gaps, 2, 2);
+        insertGaps(gaps, 0, 2);
+
+        // 0123456789
+        // --CG--AT--
+        //  XXXXXXXX
+
+        setClippedEndPosition(gaps, 9);
+        setClippedBeginPosition(gaps, 1);
+
+        {
+            std::stringstream ss;
+            ss << gaps;
+            SEQAN_ASSERT_EQ(ss.str(), "-CG--AT-");
+        }
+
+        TString seq2 = "TTTT";
+        TGaps gaps2(seq2);
+
+        copyGaps(gaps2, gaps);
+
+        {
+            std::stringstream ss;
+            ss << gaps2;
+            SEQAN_ASSERT_EQ(ss.str(), "-TT--TT-");
+        }
+    }
+}
+
+// Test copying of clipping information.
+
+template <typename TGapsSpec>
+void testAlignGapsCopyClipping(TGapsSpec const & /*spec*/)
+{
+    using namespace seqan;
+
+    typedef Dna5String                               TString;
+    typedef Gaps<TString, TGapsSpec>                 TGaps;
+
+    {
+        TString seq = "CGAT";
+        TGaps gaps(seq);
+        insertGaps(gaps, 4, 2);
+        insertGaps(gaps, 2, 2);
+        insertGaps(gaps, 0, 2);
+
+        // 0123456789
+        // --CG--AT--
+        //  XXXXXXXX
+
+        setClippedEndPosition(gaps, 9);
+        setClippedBeginPosition(gaps, 1);
+
+        {
+            std::stringstream ss;
+            ss << gaps;
+            SEQAN_ASSERT_EQ(ss.str(), "-CG--AT-");
+        }
+
+        TString seq2 = "TTTTTTTTTT";
+        TGaps gaps2(seq2);
+
+        copyClipping(gaps2, gaps);
+
+        {
+            std::stringstream ss;
+            ss << gaps2;
+            SEQAN_ASSERT_EQ(ss.str(), "TTTTTTTT");
+        }
+
+        SEQAN_ASSERT_EQ((unsigned)clippedBeginPosition(gaps2), 1u);
+        SEQAN_ASSERT_EQ((unsigned)clippedEndPosition(gaps2), 9u);
+    }
+}
+
+// Test gaps object with Nothing source.
+
+template <typename TGapsSpec>
+void testAlignGapsSourceIsNothing(TGapsSpec const & /*spec*/)
+{
+    using namespace seqan;
+
+    typedef Gaps<Nothing, TGapsSpec> TGaps;
+
+    // Test insertion of gaps.
+    {
+        TGaps gaps;
+        _setLength(gaps, 10);
+
+        SEQAN_ASSERT_EQ(unclippedLength(gaps), 10u);
+        SEQAN_ASSERT_EQ(length(gaps), 10u);
+
+        insertGap(gaps, 3);
+
+        SEQAN_ASSERT_EQ(unclippedLength(gaps), 11u);
+        SEQAN_ASSERT_EQ(length(gaps), 11u);
+        SEQAN_ASSERT(isGap(gaps, 3));
+    }
+    // Test insertion of gaps and clipping.
+    {
+        TGaps gaps;
+        _setLength(gaps, 10);
+
+        SEQAN_ASSERT_EQ(unclippedLength(gaps), 10u);
+        SEQAN_ASSERT_EQ(length(gaps), 10u);
+
+        insertGap(gaps, 3);
+        setClippedEndPosition(gaps, 9);
+        setClippedBeginPosition(gaps, 2);
+
+        SEQAN_ASSERT_EQ(unclippedLength(gaps), 11u);
+        SEQAN_ASSERT_EQ(length(gaps), 7u);
+        SEQAN_ASSERT(isGap(gaps, 1));
+    }
+}
+
 // ==========================================================================
 // Tests for Array Gaps
 // ==========================================================================
@@ -1256,6 +1386,27 @@ SEQAN_DEFINE_TEST(test_align_gaps_array_gaps_clear_clipping)
     testAlignGapsClearClipping(TTag());
 }
 
+SEQAN_DEFINE_TEST(test_align_gaps_array_gaps_copy_gaps)
+{
+    using namespace seqan;
+    typedef ArrayGaps TTag;
+    testAlignGapsCopyGaps(TTag());
+}
+
+SEQAN_DEFINE_TEST(test_align_gaps_array_gaps_copy_clipping)
+{
+    using namespace seqan;
+    typedef ArrayGaps TTag;
+    testAlignGapsCopyClipping(TTag());
+}
+
+SEQAN_DEFINE_TEST(test_align_gaps_array_gaps_source_is_nothing)
+{
+    using namespace seqan;
+    typedef ArrayGaps TTag;
+    testAlignGapsSourceIsNothing(TTag());
+}
+
 // ==========================================================================
 // Tests for Anchor Gaps
 // ==========================================================================
@@ -1421,4 +1572,27 @@ SEQAN_DEFINE_TEST(test_align_gaps_anchor_gaps_clear_clipping)
     testAlignGapsClearClipping(TTag());
 }
 
+SEQAN_DEFINE_TEST(test_align_gaps_anchor_gaps_copy_gaps)
+{
+    using namespace seqan;
+    typedef AnchorGaps<> TTag;
+    testAlignGapsCopyGaps(TTag());
+}
+
+SEQAN_DEFINE_TEST(test_align_gaps_anchor_gaps_copy_clipping)
+{
+    using namespace seqan;
+    typedef AnchorGaps<> TTag;
+    testAlignGapsCopyClipping(TTag());
+}
+
+// TODO(holtgrew): Extend anchor gaps such that this works.
+
+// SEQAN_DEFINE_TEST(test_align_gaps_anchor_gaps_source_is_nothing)
+// {
+//     using namespace seqan;
+//     typedef AnchorGaps<> TTag;
+//     testAlignGapsSourceIsNothing(TTag());
+// }
+
 #endif  // #ifndef SEQAN_CORE_TESTS_ALIGN_TEST_ALIGN_GAPS_H_
