@@ -163,6 +163,56 @@ SEQAN_DEFINE_TEST(test_store_io_read_record_context_gff)
     SEQAN_ASSERT_EQ(length(nameStore), 1u);
 }
 
+// Test for the correct reading of empty trailing attrigutes.
+SEQAN_DEFINE_TEST(test_store_io_read_record_context_empty_trailing_attribute_gff)
+{
+    std::stringstream data;
+    data << "ctg123\t.\tmRNA\t1300\t9000\t.\t+\t.\tID=mrna0001;Name=\n"
+         << "ctg123\t.\texon\t1300\t1500\t.\t+\t.\tID=exon00001;Parent=mrn a0001;Name\n";
+    data.clear();
+    data.seekg(std::ios_base::beg);
+
+    seqan::RecordReader<std::istream, seqan::SinglePass<> > reader(data);
+
+    StringSet<CharString> nameStore;
+    NameStoreCache<StringSet<CharString> > nameStoreCache(nameStore);
+    GffIOContext<StringSet<CharString> > gffIOContext(nameStore, nameStoreCache);
+
+    seqan::GffRecord record;
+    seqan::readRecord(record, reader, gffIOContext, seqan::Gff());
+
+    SEQAN_ASSERT_EQ(record.ref, "ctg123");
+    SEQAN_ASSERT_EQ(record.source, "");
+    SEQAN_ASSERT_EQ(record.type, "mRNA");
+    SEQAN_ASSERT_EQ(record.beginPos, 1299u);
+    SEQAN_ASSERT_EQ(record.endPos, 9000u);
+    SEQAN_ASSERT_NEQ(record.score, record.score);
+    SEQAN_ASSERT_EQ(record.strand, '+');
+    SEQAN_ASSERT_EQ(record.phase, '.');
+    SEQAN_ASSERT_EQ(record.tagName[0], "ID");
+    SEQAN_ASSERT_EQ(record.tagValue[0], "mrna0001");
+    SEQAN_ASSERT_EQ(record.tagName[1], "Name");
+    SEQAN_ASSERT_EQ(record.tagValue[1], "");
+    SEQAN_ASSERT_EQ(length(nameStore), 1u);
+
+    seqan::readRecord(record, reader, gffIOContext, seqan::Gff());
+    SEQAN_ASSERT_EQ(record.ref, "ctg123");
+    SEQAN_ASSERT_EQ(record.source, "");
+    SEQAN_ASSERT_EQ(record.type, "exon");
+    SEQAN_ASSERT_EQ(record.beginPos, 1299u);
+    SEQAN_ASSERT_EQ(record.endPos, 1500u);
+    SEQAN_ASSERT_NEQ(record.score, record.score);
+    SEQAN_ASSERT_EQ(record.strand, '+');
+    SEQAN_ASSERT_EQ(record.phase, '.');
+    SEQAN_ASSERT_EQ(record.tagName[0], "ID");
+    SEQAN_ASSERT_EQ(record.tagValue[0], "exon00001");
+    SEQAN_ASSERT_EQ(record.tagName[1], "Parent");
+    SEQAN_ASSERT_EQ(record.tagValue[1], "mrn a0001");
+    SEQAN_ASSERT_EQ(length(nameStore), 1u);
+
+    SEQAN_ASSERT(atEnd(reader));
+}
+
 SEQAN_DEFINE_TEST(test_store_io_write_record_gff)
 {
     seqan::CharString gffPath = SEQAN_PATH_TO_ROOT();
@@ -187,7 +237,7 @@ SEQAN_DEFINE_TEST(test_store_io_write_record_gff)
 
     fout.close();
 
-    SEQAN_ASSERT(seqan::_compareTextFiles(toCString(outPath), toCString(gffPath)));
+    SEQAN_ASSERT(seqan::_compareTextFilesAlt(toCString(outPath), toCString(gffPath)));
 }
 
 SEQAN_DEFINE_TEST(test_store_io_write_record_context_gff)
@@ -226,7 +276,7 @@ SEQAN_DEFINE_TEST(test_store_io_write_record_context_gff)
     String<char> goldPath = SEQAN_PATH_TO_ROOT();
     append(goldPath, "/core/tests/gff_io/example_gff_context.tsv");
 
-    SEQAN_ASSERT(seqan::_compareTextFiles(toCString(outPath), toCString(goldPath)));
+    SEQAN_ASSERT(seqan::_compareTextFilesAlt(toCString(outPath), toCString(goldPath)));
 }
 
 
@@ -252,9 +302,11 @@ SEQAN_DEFINE_TEST(test_store_io_read_record_gtf)
     SEQAN_ASSERT_EQ(record.strand, '-');
     SEQAN_ASSERT_EQ(record.phase, '.');
     SEQAN_ASSERT_EQ(record.tagName[0], "gene_id");
-    SEQAN_ASSERT_EQ(record.tagValue[0], "1");
+    SEQAN_ASSERT_EQ(record.tagValue[0], "gene1");
     SEQAN_ASSERT_EQ(record.tagName[1], "transcript_id");
-    SEQAN_ASSERT_EQ(record.tagValue[1], "2");
+    SEQAN_ASSERT_EQ(record.tagValue[1], "trans2");
+    SEQAN_ASSERT_EQ(record.tagName[2], "position");
+    SEQAN_ASSERT_EQ(record.tagValue[2], "43");
 
     seqan::readRecord(record, reader, seqan::Gtf());
     SEQAN_ASSERT_EQ(record.ref, "240");
@@ -380,9 +432,11 @@ SEQAN_DEFINE_TEST(test_store_io_read_record_context_gtf)
     SEQAN_ASSERT_EQ(record.strand, '-');
     SEQAN_ASSERT_EQ(record.phase, '.');
     SEQAN_ASSERT_EQ(record.tagName[0], "gene_id");
-    SEQAN_ASSERT_EQ(record.tagValue[0], "1");
+    SEQAN_ASSERT_EQ(record.tagValue[0], "gene1");
     SEQAN_ASSERT_EQ(record.tagName[1], "transcript_id");
-    SEQAN_ASSERT_EQ(record.tagValue[1], "2");
+    SEQAN_ASSERT_EQ(record.tagValue[1], "trans2");
+    SEQAN_ASSERT_EQ(record.tagName[2], "position");
+    SEQAN_ASSERT_EQ(record.tagValue[2], "43");
     SEQAN_ASSERT_EQ(length(nameStore), 1u);
 
     seqan::readRecord(record, reader, gffIOContext, seqan::Gtf());
@@ -440,7 +494,7 @@ SEQAN_DEFINE_TEST(test_store_io_write_record_gtf)
 
     fout.close();
 
-    SEQAN_ASSERT(seqan::_compareTextFiles(toCString(outPath), toCString(gtfPath)));
+    SEQAN_ASSERT(seqan::_compareTextFilesAlt(toCString(outPath), toCString(gtfPath)));
 }
 
 SEQAN_DEFINE_TEST(test_store_io_write_record_context_gtf)
@@ -481,7 +535,7 @@ SEQAN_DEFINE_TEST(test_store_io_write_record_context_gtf)
 
     // std::cerr << toCString(outPath) << std::endl;
 
-    SEQAN_ASSERT(seqan::_compareTextFiles(toCString(outPath), toCString(goldPath)));
+    SEQAN_ASSERT(seqan::_compareTextFilesAlt(toCString(outPath), toCString(goldPath)));
 }
 
 SEQAN_DEFINE_TEST(test_store_io_gff_stream_read_record_gff)
@@ -559,9 +613,9 @@ SEQAN_DEFINE_TEST(test_store_io_gff_stream_read_record_gtf)
     SEQAN_ASSERT_EQ(record.strand, '-');
     SEQAN_ASSERT_EQ(record.phase, '.');
     SEQAN_ASSERT_EQ(record.tagName[0], "gene_id");
-    SEQAN_ASSERT_EQ(record.tagValue[0], "1");
+    SEQAN_ASSERT_EQ(record.tagValue[0], "gene1");
     SEQAN_ASSERT_EQ(record.tagName[1], "transcript_id");
-    SEQAN_ASSERT_EQ(record.tagValue[1], "2");
+    SEQAN_ASSERT_EQ(record.tagValue[1], "trans2");
 
     SEQAN_ASSERT_EQ(readRecord(record, gffStream), 0);
     SEQAN_ASSERT_EQ(record.ref, "240");
@@ -621,7 +675,7 @@ SEQAN_DEFINE_TEST(test_store_io_gff_stream_write_record_gff)
 
     flush(outStream);
 
-    SEQAN_ASSERT(seqan::_compareTextFiles(toCString(outPath), toCString(gtfPath)));
+    SEQAN_ASSERT(seqan::_compareTextFilesAlt(toCString(outPath), toCString(gtfPath)));
 }
 
 SEQAN_DEFINE_TEST(test_store_io_gff_stream_write_record_gtf)
@@ -653,7 +707,7 @@ SEQAN_DEFINE_TEST(test_store_io_gff_stream_write_record_gtf)
 
     flush(outStream);
 
-    SEQAN_ASSERT(seqan::_compareTextFiles(toCString(outPath), toCString(gtfPath)));
+    SEQAN_ASSERT(seqan::_compareTextFilesAlt(toCString(outPath), toCString(gtfPath)));
 }
 
 #endif  // CORE_TESTS_GFF_IO_TEST_GFF_IO_H_
