@@ -41,6 +41,68 @@
 namespace SEQAN_NAMESPACE_MAIN
 {
 
+SEQAN_DEFINE_TEST(testEmptyIndex)
+{
+    typedef String<Dna5> TString;
+    typedef Index<TString> TIndex;
+
+    TIndex index;
+
+    Iterator<TIndex, TopDown<> >::Type iterator(index);
+
+}
+
+SEQAN_DEFINE_TEST(testIssue509)
+{
+    // goDown causes assertion on small index #509
+    // Originally by John on Trac
+    typedef String<Dna5> TString;
+    typedef StringSet<TString> TStrings;
+    typedef Index<TStrings> TIndex;
+
+    TStrings seqs;
+    TString seq("A");
+    appendValue(seqs, seq);
+    TIndex index(seqs);
+
+    Iterator<TIndex, TopDown<> >::Type iterator(index);
+    SEQAN_ASSERT(isRoot(iterator));
+    SEQAN_ASSERT_NOT(isLeaf(iterator));
+
+    SEQAN_ASSERT(goDown(iterator));
+    SEQAN_ASSERT_NOT(isRoot(iterator));
+    SEQAN_ASSERT(isLeaf(iterator));
+
+    goRoot(iterator);
+    SEQAN_ASSERT(isRoot(iterator));
+    SEQAN_ASSERT_NOT(isLeaf(iterator));
+    SEQAN_ASSERT(goDown(iterator, seq));
+}
+
+SEQAN_DEFINE_TEST(testIssue509b)
+{
+    // goDown causes assertion on small index #509
+    // Originally by John on Trac
+    typedef String<Dna5> TString;
+    typedef Index<TString> TIndex;
+
+    TString seq("A");
+    TIndex index(seq);
+
+    Iterator<TIndex, TopDown<> >::Type iterator(index);
+    SEQAN_ASSERT(isRoot(iterator));
+    SEQAN_ASSERT_NOT(isLeaf(iterator));
+
+    SEQAN_ASSERT(goDown(iterator));
+    SEQAN_ASSERT_NOT(isRoot(iterator));
+    SEQAN_ASSERT(isLeaf(iterator));
+
+    goRoot(iterator);
+    SEQAN_ASSERT(isRoot(iterator));
+    SEQAN_ASSERT_NOT(isLeaf(iterator));
+    SEQAN_ASSERT(goDown(iterator, seq));
+}
+
 SEQAN_DEFINE_TEST(testBuild)
 {
 		typedef String<char> TText;
@@ -87,6 +149,18 @@ SEQAN_DEFINE_TEST(testMultiIndex)
 		//t[4] = "ill";
 		//t[5] = "wow";
 
+        // test empty stringsets
+        {
+            typedef Index<TMulti> TIndex;
+            TMulti emptyStringSet;
+
+            TIndex index(emptyStringSet);
+            Iterator<
+                TIndex,
+                TopDown<>
+            >::Type iterator(index);
+        }
+
 		t[0] = "caggctcgcgt";
 		t[1] = "caggaacg";
 		t[2] = "tcgttg";
@@ -271,7 +345,7 @@ void compareIndices()
 		t[4] = "agg";
 		t[5] = "ctg";
 		Index<StringSet<DnaString>, TIndexSpec1> index1(t);
-		Index<StringSet<DnaString>, TIndexSpec2 > index2(t);
+		Index<StringSet<DnaString>, TIndexSpec2> index2(t);
 		compareTreeIterators(index1, index2);
 	}
 }
@@ -298,7 +372,7 @@ void testSTreeIterators()
         SEQAN_ASSERT_NOT(goRight(iter));
         SEQAN_ASSERT_NOT(goUp(piter));
     }
-    
+
     {
         String<char> text("acaaacatatz");
 //		String<char> text("AAAAAGGGGG");
@@ -618,6 +692,19 @@ SEQAN_DEFINE_TEST(testFind_Esa_Mlr)
 	testFind<EsaFindMlr>();
 }
 
+SEQAN_DEFINE_TEST(testMultipleStrings_Ticket1109)
+{
+    StringSet<String<char> > text;
+    appendValue(text, "How many");
+    appendValue(text, " wood would");
+    appendValue(text, " a woodchuck chuck?");
+    
+    typedef Index<StringSet<CharString> > TIndex;
+    TIndex index(text);
+    
+    Iterator< TIndex, TopDown<> >::Type it(index);
+}
+
 //////////////////////////////////////////////////////////////////////////////
 
 
