@@ -448,13 +448,22 @@ template <typename TMe>
 void TestStringResize()
 {
 	TMe str1;
-	resize(str1, 50);
+	resize(str1, 5, 1);
+	SEQAN_ASSERT_EQ(length(str1), 5u);
+	SEQAN_ASSERT_EQ((int)ordValue(getValue(str1, 1)), 1);
+	SEQAN_ASSERT_EQ((int)ordValue(getValue(str1, 3)), 1);
+
+	resize(str1, 50, 2);
 	SEQAN_ASSERT_EQ(length(str1), 50u);
+	SEQAN_ASSERT_EQ((int)ordValue(getValue(str1, 4)), 1);
+	SEQAN_ASSERT_EQ((int)ordValue(getValue(str1, 5)), 2);
 
 	resize(str1, 100, 3);
 	SEQAN_ASSERT_EQ(length(str1), 100u);
-	SEQAN_ASSERT_EQ(getValue(str1, 51), 3);
-	SEQAN_ASSERT_EQ(getValue(str1, 99), 3);
+	SEQAN_ASSERT_EQ((int)ordValue(getValue(str1, 49)), 2);
+	SEQAN_ASSERT_EQ((int)ordValue(getValue(str1, 50)), 3);
+	SEQAN_ASSERT_EQ((int)ordValue(getValue(str1, 51)), 3);
+	SEQAN_ASSERT_EQ((int)ordValue(getValue(str1, 99)), 3);
 
 }
 
@@ -524,9 +533,90 @@ SEQAN_DEFINE_TEST(String_Packed)
     SEQAN_CHECKPOINT;
 	TestStringBasics<String<char, Packed<> > >();
 	TestStringBasics<String<Dna, Packed<> > >();
+	TestStringBasics<String<Dna5, Packed<> > >();
 
 	TestStringResize<String<char, Packed<> > >();
+	TestStringResize<String<Dna, Packed<> > >();
+	TestStringResize<String<Dna5, Packed<> > >();
 
+    typedef String<Dna5, Packed<> > TPackedString;
+    Dna5String str1;
+    TPackedString str2;
+    Dna5String motif = "AGAGCCCTGACACACTGATTATGACACGTAAGACTCTGAGAGTCCGTGTCTCTATAG";
+
+    for (int i = 0; i < 5; ++i)
+    {
+        append(str1, "GATTACATATA", Exact());
+        append(str2, "GATTACATATA", Exact());
+        SEQAN_ASSERT_EQ(str1, str2);
+    }
+
+    for (int i = 0; i < PackedTraits_<TPackedString>::VALUES_PER_HOST_VALUE; ++i)
+    {
+        appendValue(str1, (Dna5)(i % 5), Exact());
+        appendValue(str2, (Dna5)(i % 5), Exact());
+        SEQAN_ASSERT_EQ(str1, str2);
+    }
+
+    resize(str1, 131, 'G', Exact());
+    resize(str2, 131, 'G', Exact());
+    SEQAN_ASSERT_EQ(str1, str2);
+
+    insert(str1, 19, "ACGTACGT", Exact());
+    insert(str2, 19, "ACGTACGT", Exact());
+    SEQAN_ASSERT_EQ(str1, str2);
+
+    for (int i = 0; i < PackedTraits_<TPackedString>::VALUES_PER_HOST_VALUE; ++i)
+    {
+        Dna5String str1_ = str1;
+        TPackedString str2_ = str2;
+
+        insertValue(str1_, 64-i, (Dna5)(i % 5), Exact());
+        insertValue(str2_, 64-i, (Dna5)(i % 5), Exact());
+        SEQAN_ASSERT_EQ(str1_, str2_);
+    }
+
+    for (int i = 0; i < PackedTraits_<TPackedString>::VALUES_PER_HOST_VALUE; ++i)
+    {
+        Dna5String str1_ = str1;
+        TPackedString str2_ = str2;
+
+        insert(str1_, 64-i, "ACGTACGT", Exact());
+        insert(str2_, 64-i, "ACGTACGT", Exact());
+        SEQAN_ASSERT_EQ(str1_, str2_);
+    }
+
+    for (int i = 0; i < PackedTraits_<TPackedString>::VALUES_PER_HOST_VALUE; ++i)
+        for (int j = 0; j < PackedTraits_<TPackedString>::VALUES_PER_HOST_VALUE; ++j)
+        {
+            Dna5String str1_ = str1;
+            TPackedString str2_ = str2;
+
+            insert(str1_, 64-i, suffix(motif,j), Exact());
+            insert(str2_, 64-i, suffix(motif,j), Exact());
+            SEQAN_ASSERT_EQ(str1_, str2_);
+        }
+
+    for (int i = 0; i < PackedTraits_<TPackedString>::VALUES_PER_HOST_VALUE; ++i)
+    {
+        Dna5String str1_ = str1;
+        TPackedString str2_ = str2;
+
+        erase(str1_, 64-i);
+        erase(str2_, 64-i);
+        SEQAN_ASSERT_EQ(str1_, str2_);
+    }
+
+    for (int i = 0; i < PackedTraits_<TPackedString>::VALUES_PER_HOST_VALUE; ++i)
+        for (int j = 0; j < PackedTraits_<TPackedString>::VALUES_PER_HOST_VALUE; ++j)
+        {
+            Dna5String str1_ = str1;
+            TPackedString str2_ = str2;
+
+            erase(str1_, 64-i, 65-i+j);
+            erase(str2_, 64-i, 65-i+j);
+            SEQAN_ASSERT_EQ(str1_, str2_);
+        }
 }
 
 //////////////////////////////////////////////////////////////////////////////
@@ -1186,7 +1276,7 @@ SEQAN_DEFINE_TEST(Combinatoric)
 	Test_Assignments_Combinatoric(str9, str1, Limit(), 10);
 }
 
-SEQAN_DEFINE_TEST(ticket_901)
+SEQAN_DEFINE_TEST(ticket901)
 {
     using namespace seqan;
     
@@ -1198,3 +1288,42 @@ SEQAN_DEFINE_TEST(ticket_901)
     SEQAN_ASSERT_EQ(length(source), 0u);
     SEQAN_ASSERT_EQ(target, DnaString("acgtgcat"));
 }
+
+SEQAN_DEFINE_TEST(ticket1108)
+{
+    static const unsigned int ARRAY_SIZE = 3u;
+    typedef String<unsigned int, Array<ARRAY_SIZE> > TArray;
+
+    {
+        typedef String<TArray, MMap<> > TString;
+
+        TString str;
+        for (unsigned int i = 0u; i < 64u; ++i)
+        {
+//            std::cerr << i << ", " << std::endl;
+            TArray elem;
+            resize(elem, ARRAY_SIZE);
+            appendValue(str, elem);
+            SEQAN_ASSERT_LEQ(length(elem), ARRAY_SIZE);
+            SEQAN_ASSERT_LEQ(length(str[0u]), ARRAY_SIZE); // Is violated as soon as i reaches 48.
+            if (length(str) > 32u) SEQAN_ASSERT_LEQ(length(str[32u]), ARRAY_SIZE);
+        }
+    }
+
+    {
+        typedef ExternalConfig<ExternalConfig<>::TFile, 16u, ExternalConfig<>::FRAMES> TExternalConfig;
+        typedef String<TArray, External<TExternalConfig> > TString;
+
+        TString str;
+        for (unsigned int i = 0u; i < 64u; ++i)
+        {
+//            std::cerr << i << ", " << std::endl;
+            TArray elem;
+            resize(elem, ARRAY_SIZE);
+            appendValue(str, elem);
+            SEQAN_ASSERT_LEQ(length(elem), ARRAY_SIZE);
+            SEQAN_ASSERT_LEQ(length(str[0u]), ARRAY_SIZE); // Is violated as soon as i reaches 48.
+            if (length(str) > 32u) SEQAN_ASSERT_LEQ(length(str[32u]), ARRAY_SIZE);
+        }
+    }
+}
