@@ -65,7 +65,6 @@ void testJournaledStringAssign(TStringJournalSpec const &)
     // Test assignment operator with other string type.
     {
         journaledString = charStr2;
-        journaledString = charStr2;
 
         std::stringstream tmp1;
         tmp1 << journaledString;
@@ -93,6 +92,7 @@ void testJournaledStringAssign(TStringJournalSpec const &)
 
     // Test assignment operator with same journaled string type.
     {
+        // We need to copy over all information from the source to the target.
         journaledString = journaledString2;
 
         std::stringstream tmp1;
@@ -101,7 +101,7 @@ void testJournaledStringAssign(TStringJournalSpec const &)
 
         std::stringstream tmp2;
         tmp2 << host(journaledString);
-        SEQAN_ASSERT_EQ("test", tmp2.str());
+        SEQAN_ASSERT_EQ("not a test!", tmp2.str());
     }
 
     // Test assign() with same journaled string type.
@@ -114,7 +114,7 @@ void testJournaledStringAssign(TStringJournalSpec const &)
 
         std::stringstream tmp2;
         tmp2 << host(journaledString);
-        SEQAN_ASSERT_EQ("test", tmp2.str());
+        SEQAN_ASSERT_EQ("not a test!", tmp2.str());
     }
 }
 
@@ -157,6 +157,33 @@ void testJournaledStringSet(TStringJournalSpec const &)
     }
 }
 
+template <typename TJournalSpec>
+void testJournaledStringReset(TJournalSpec const & /*spec*/)
+{
+    CharString hostStr = "test";
+
+    String<char, Journaled<Alloc<>, TJournalSpec> > journaledString(hostStr);
+
+    insert(journaledString, 4, "XXL");
+    erase(journaledString, 1, 2);
+
+    std::stringstream test;
+    test << journaledString;
+
+    SEQAN_ASSERT_EQ(test.str(), "tstXXL");
+    reset(journaledString);
+
+    test.str("");
+    test.clear();
+    test << journaledString;
+
+    SEQAN_ASSERT_EQ(test.str(), "");
+    SEQAN_ASSERT_EQ(empty(journaledString._holder), true);
+    SEQAN_ASSERT_EQ(empty(journaledString._insertionBuffer), true);
+    SEQAN_ASSERT_EQ(length(journaledString), 0u);
+}
+
+
 // Test setHost(), host().
 template <typename TStringJournalSpec>
 void testJournaledStringHost(TStringJournalSpec const &)
@@ -674,7 +701,7 @@ void testJournaledStringCopyConstructor(TStringJournalSpec const &)
 }
 
 template <typename TStringJournalSpec>
-void testJournaledStringBeginEndIterator(TStringJournalSpec const &)
+void testJournaledStringBeginEndIteratorStandard(TStringJournalSpec const &)
 {
     CharString charStr = "test";
     typedef String<char, Journaled<Alloc<void>, TStringJournalSpec> > TJournaledString;
@@ -685,13 +712,37 @@ void testJournaledStringBeginEndIterator(TStringJournalSpec const &)
 
     {  // Test pre-increment iteration.
         CharString buffer;
-        for (TIterator it = begin(journaledString), itend = end(journaledString); it != itend; ++it)
+        for (TIterator it = begin(journaledString, Standard()), itend = end(journaledString, Standard()); it != itend; ++it)
             appendValue(buffer, *it);
         SEQAN_ASSERT_EQ("teXst", buffer);
     }
     {  // Test post-increment iteration.
         CharString buffer;
-        for (TIterator it = begin(journaledString), itend = end(journaledString); it != itend; it++)
+        for (TIterator it = begin(journaledString, Standard()), itend = end(journaledString, Standard()); it != itend; it++)
+            appendValue(buffer, *it);
+        SEQAN_ASSERT_EQ("teXst", buffer);
+    }
+}
+
+template <typename TStringJournalSpec>
+void testJournaledStringBeginEndIteratorRooted(TStringJournalSpec const &)
+{
+    CharString charStr = "test";
+    typedef String<char, Journaled<Alloc<void>, TStringJournalSpec> > TJournaledString;
+    TJournaledString journaledString(charStr);
+    insert(journaledString, 2, 'X');
+
+    typedef typename Iterator<TJournaledString, Rooted>::Type TIterator;
+
+    {  // Test pre-increment iteration.
+        CharString buffer;
+        for (TIterator it = begin(journaledString, Rooted()), itend = end(journaledString, Rooted()); it != itend; ++it)
+            appendValue(buffer, *it);
+        SEQAN_ASSERT_EQ("teXst", buffer);
+    }
+    {  // Test post-increment iteration.
+        CharString buffer;
+        for (TIterator it = begin(journaledString, Rooted()), itend = end(journaledString, Rooted()); it != itend; it++)
             appendValue(buffer, *it);
         SEQAN_ASSERT_EQ("teXst", buffer);
     }
@@ -1141,6 +1192,12 @@ SEQAN_DEFINE_TEST(test_sequence_journaled_unbalanced_tree_length) {
     testJournaledStringLength(UnbalancedTree());
 }
 
+SEQAN_DEFINE_TEST(test_sequence_journaled_unbalanced_tree_reset)
+{
+    testJournaledStringReset(seqan::UnbalancedTree());
+}
+
+
 
 SEQAN_DEFINE_TEST(test_sequence_journaled_unbalanced_tree_virtual_to_host_position) {
     testJournaledStringVirtualToHostPosition<UnbalancedTree>();
@@ -1157,7 +1214,8 @@ SEQAN_DEFINE_TEST(test_sequence_journaled_unbalanced_tree_copy_constructor) {
 
 
 SEQAN_DEFINE_TEST(test_sequence_journaled_unbalanced_tree_begin_end_iterator) {
-    testJournaledStringBeginEndIterator(UnbalancedTree());
+    testJournaledStringBeginEndIteratorStandard(UnbalancedTree());
+    testJournaledStringBeginEndIteratorRooted(UnbalancedTree());
 }
 
 
@@ -1256,6 +1314,11 @@ SEQAN_DEFINE_TEST(test_sequence_journaled_sorted_array_host_to_virtual_position)
     testJournaledStringHostToVirtualPosition<SortedArray>();
 }
 
+SEQAN_DEFINE_TEST(test_sequence_journaled_sorted_array_reset)
+{
+    testJournaledStringReset(seqan::SortedArray());
+}
+
 
 
 SEQAN_DEFINE_TEST(test_sequence_journaled_sorted_array_copy_constructor) {
@@ -1264,7 +1327,8 @@ SEQAN_DEFINE_TEST(test_sequence_journaled_sorted_array_copy_constructor) {
 
 
 SEQAN_DEFINE_TEST(test_sequence_journaled_sorted_array_begin_end_iterator) {
-    testJournaledStringBeginEndIterator(SortedArray());
+    testJournaledStringBeginEndIteratorStandard(SortedArray());
+    testJournaledStringBeginEndIteratorRooted(SortedArray());
 }
 
 
